import { useState, useEffect } from 'react';
import axios from 'axios';
import {host} from "@/utils";

const useCommitDetails = (projectId: string, commitId: string, token: string) => {
    const [commit, setCommitDetails] = useState(null);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);

    useEffect(() => {
        const fetchCommitDetails = async () => {
            setLoading(true);
            try {
                const response = await axios.get(`${host}/api/v4/projects/${projectId}/repository/commits/${commitId}`, {
                    headers: { 'PRIVATE-TOKEN': token }
                });
                setCommitDetails(response.data);
            } catch (err) {
                setError(err);
            } finally {
                setLoading(false);
            }
        };

        fetchCommitDetails();
    }, [projectId, commitId, token]);

    return { commit, loading, error };
};

export default useCommitDetails;
