import { useState, useEffect } from 'react';
import axios from 'axios';

const useCommits = (projectId: string, token: string, host: string) => {
    const [commits, setCommits] = useState([]);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);

    useEffect(() => {
        setCommits([]);
        setError(null);

        const fetchCommits = async () => {
            setLoading(true);
            try {
                const response = await axios.get(`${host}/api/v4/projects/${projectId}/repository/commits`, {
                    headers: { 'PRIVATE-TOKEN': token }
                });
                setCommits(response.data);
            } catch (err) {
                setError(err);
            } finally {
                setLoading(false);
            }
        };

        fetchCommits();
    }, [host, projectId, token]);

    return { commits, loading, error };
};

export default useCommits;
